#
# Cookbook Name:: ccondor
# Recipe:: cm
#
# Copyright 2010, Cycle Computing
#
# All rights reserved - Do Not Redistribute

include_recipe "jetpack"
include_recipe "ccondor::default"

if node[:os] == "windows"
  cookbook_file "C:\\condor\\condor_config" do
    source "condor_config-windows.cm"
    mode "0644"
  end
else
  cookbook_file "/opt/condor/condor_config.cm" do
    path "/opt/condor/condor_config"
    source "condor_config.cm"
    owner "root"
    group "root"
    mode "0644"
  end
end

if !node[:htcondor].nil? && node[:os] == "windows"

  template "C:\\condor\\condor_config.local" do
    source "local_config_cm_for_win.erb"
    mode 0644
    notifies :run, "execute[condor-reconfig]"
  end
else

  template "CM: /opt/condor/local_config.sh" do
    path "/opt/condor/local_config.sh"
    source "local_config_cm.sh.erb"
    mode "0644"
    owner "root"
    group "root"
  end

end

unless node[:os] == "windows"
  template "CM: /mnt/condor_data/condor_config.cloud" do
    path "/mnt/condor_data/condor_config.cloud"
    source "condor-config-local-cm.erb"
    mode "0644"
    owner "root"
    group "root"

    notifies :run, "execute[condor-reconfig]"
  end
end

include_recipe "ccondor::poolpass"

service "CM: condor" do
  service_name "condor"
  unless node[:os] == "windows"
    supports :status => true, :restart => true
  end
  action [:enable, :start]
end

# Notify CycleCloud that node is a Condor Central Manager
monitoring_config = "#{node['cyclecloud']['home']}/config/service.d/htcondor.json"
file monitoring_config do
  content <<-EOH
  {
    "system": "htcondor",
    "cluster_name": "#{node[:cyclecloud][:cluster][:name]}",
    "hostname": "#{node[:cyclecloud][:instance][:public_hostname]}",
    "ports": {"ssh": 22}
  }
  EOH
  mode "0750"
  not_if { ::File.exist?(monitoring_config) }
end

jetpack_send "Registering HTCondor Central Manager for monitoring." do
  file monitoring_config
  routing_key "#{node[:cyclecloud][:service_status][:routing_key]}.htcondor"
end

include_recipe "ccondor::autostart"
