legacy_bootstrap = '/root/bootstrap'
jetpack_bootstrap = '/opt/cycle/jetpack/system/bootstrap'
legacy_home = '/opt/cyclecloud'
jetpack_home = '/opt/cycle/jetpack'

if node['os'] == 'windows'
  legacy_bootstrap = 'C:\Users\Administrator\bootstrap'
  jetpack_bootstrap = 'C:\cycle\jetpack\system\bootstrap'
  legacy_home = 'C:\cyclecloud'
  jetpack_home = 'C:\cycle\jetpack'
end

# The following hacks are temporary until the cookbooks are fixed to work with the new jetpack iamges.
# Jetpack images use different install locations as well as embedded version of Python and Ruby. Once
# the cookbooks are updated to reflect this change these hacks can be removed.
if ::File.exist? "#{jetpack_home}/version.txt"
  if node['cyclecloud']['compatibility']['get_config_val'] && node['os'] == 'linux'
    cookbook_file "#{jetpack_home}/bin/get_config_val" do
      source 'get_config_val.sh'
      mode '0755'
    end
  end

  if node['cyclecloud']['compatibility']['legacy_bootstrap']
    link legacy_bootstrap do
      to jetpack_bootstrap
      not_if { ::File.exist?(legacy_bootstrap) }
    end
  end

  if node['cyclecloud']['compatibility']['legacy_home']
    link legacy_home do
      to jetpack_home
      not_if { ::File.exist?(legacy_home) }
    end
  end

  if node['cyclecloud']['compatibility']['legacy_paths']
    if node['os'] == 'windows' && Chef::VERSION.to_f >= 11
      env 'add embedded/bin HACK' do
        action :modify
        delim ::File::PATH_SEPARATOR
        key_name 'PATH'
        value 'C:\\cycle\\jetpack\\system\\embedded\\bin'
      end
      env 'add embedded/python HACK' do
        action :modify
        delim ::File::PATH_SEPARATOR
        key_name 'PATH'
        value 'C:\\cycle\\jetpack\\system\\embedded\\python'
      end
    elsif node['os'] == 'linux'
      cookbook_file '/etc/profile.d/cyclecloud-compatibility.sh' do
        source 'cyclecloud-compatibility.sh'
        mode '0755'
      end
    end
  end
end

# The following are hacks for 'forwards' compatibility. This will make old images (pre-jetpack)
# look like jetpack images. This can be kept around until we no longer support legacy images.

unless ::File.exist? "#{jetpack_home}/version.txt"

  # Ensure that chef cache dir exists prior to gem install
  unless ::File.directory?(Chef::Config['file_cache_path'])
    require 'fileutils'
    ::FileUtils.mkdir_p(Chef::Config['file_cache_path'])
  end

  directory "#{jetpack_home}/system" do
    recursive true
  end

  #  directory "#{legacy_home}/system/bin" do
  #    recursive true
  #  end

  %w( bin system/bin config ).each do |d|
    directory "#{legacy_home}/#{d}" do
      recursive true
    end

    link "#{jetpack_home}/#{d}" do
      to "#{legacy_home}/#{d}"
    end
  end

  # Set upa  symlink to legacy bootstrap
  link jetpack_bootstrap do
    to legacy_bootstrap
  end

  # Install legacy version (python) of get_config_val on linux
  if node['os'] == 'linux'
    cookbook_file "#{jetpack_home}/bin/get_config_val" do
      source 'get_config_val.py'
      mode '0755'
    end
  end

  # Create a mock cyclecloud-env.sh file
  file "#{jetpack_home}/system/bin/cyclecloud-env.sh" do
    mode 00755
    content '#!/bin/bash'
    only_if { node['os'] == 'linux' }
  end

  # Create a mock cyclecloud-env.bat file
  file "#{jetpack_home}/system/bin/cyclecloud-env.bat" do
    content '@echo off'
    only_if { node['os'] == 'windows' }
  end

  # Add jetpack/bin to the path so users can use stuff there
  if node['os'] == 'windows'
    env 'add jetpack/bin to path' do
      action :modify
      delim ::File::PATH_SEPARATOR
      key_name 'PATH'
      value "#{jetpack_home}\\bin"
    end
  else
    file '/etc/profile.d/cyclecloud-jetpack.sh' do
      content <<-EOH
#!/bin/bash
export PATH=$PATH:#{jetpack_home}/bin
            EOH
      mode 00755
    end
  end

end
