require 'spec_helper'

shared_examples 'yum cache clean' do
  it 'installs deltarpm' do
    expect(chef_run).to install_package('deltarpm')
  end

  it 'yum clean all' do
    yum_clean_all = chef_run.execute('yum clean all')
    yum_conf = 'replace_or_add[turn off http_caching in yum.conf]'
    expect(yum_clean_all).to do_nothing
    expect(yum_clean_all).to subscribe_to(yum_conf)
  end

  it 'converges successfully' do
    expect { chef_run }.to_not raise_error
  end
end

shared_examples 'do nothing' do
  it 'does not install deltarpm' do
    expect(chef_run).to_not install_package('deltarpm')
  end

  it 'does not yum clean all' do
    expect(chef_run).to_not run_execute('yum clean all')
  end

  it 'converges successfully' do
    expect { chef_run }.to_not raise_error
  end
end

shared_examples 'openlogic publisher' do |platform, version|
  context "On #{platform} #{version}" do
    cached(:chef_run) do
      ChefSpec::ServerRunner.new(platform: platform, version: version) do |node|
        node.automatic['azure']['metadata']['compute']['publisher'] = 'OpenLogic'
      end.converge(described_recipe)
    end

    it_behaves_like 'yum cache clean'
  end
end

shared_examples 'microsoft-ads publisher' do |platform, version|
  context "On #{platform} #{version}" do
    cached(:chef_run) do
      ChefSpec::ServerRunner.new(platform: platform, version: version) do |node|
        node.automatic['azure']['metadata']['compute']['publisher'] = 'microsoft-ads'
      end.converge(described_recipe)
    end

    it_behaves_like 'do nothing'
  end
end

shared_examples 'custom az image' do |platform, version|
  context "On #{platform} #{version} - no publisher" do
    cached(:chef_run) do
      ChefSpec::ServerRunner.new(platform: platform, version: version) do |node|
        node.automatic['azure']['metadata']['compute']['name'] = 'my-custom-az-image'
      end.converge(described_recipe)
    end

    it_behaves_like 'do nothing'
  end

  context "On #{platform} #{version} - empty publisher" do
    cached(:chef_run) do
      ChefSpec::ServerRunner.new(platform: platform, version: version) do |node|
        node.automatic['azure']['metadata']['compute'] = {
          publisher: '',
          offer: '',
          sku: '',
          name: 'my-custom-az-image',
        }
      end.converge(described_recipe)
    end

    it_behaves_like 'do nothing'
  end

  context "On #{platform} #{version} - nil publisher" do
    cached(:chef_run) do
      ChefSpec::ServerRunner.new(platform: platform, version: version) do |node|
        node.automatic['azure']['metadata']['compute'] = {
          publisher: nil,
          offer: '',
          sku: '',
          name: 'my-custom-az-image',
        }
      end.converge(described_recipe)
    end

    it_behaves_like 'do nothing'
  end
end

describe 'cyclecloud::_yum_cache' do
  platforms = {
    'centos' => ['7.4.1708'],
  }

  platforms.each do |platform, versions|
    versions.each do |version|
      it_behaves_like 'openlogic publisher', platform, version
      it_behaves_like 'microsoft-ads publisher', platform, version
      it_behaves_like 'custom az image', platform, version
    end
  end
end
